ConcurrentStore

Trait ConcurrentStore 

pub trait ConcurrentStore: for<'c> Store<Connection<'c> = Self::ConcurrentConnection<'c>> {
    type ConcurrentConnection<'c>: ConcurrentConnection
       where Self: 'c;

    const DELIMITER: &'static str = "@";
}
Extension of Store for stores that support concurrent pipeline operations, including task-based pipeline watermark tracking.

Provided Associated Constants

const DELIMITER: &'static str = "@"

Delimiter used to separate pipeline names from task identifiers when reading or writing the committer watermark.

Required Associated Types

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors